@@ -76,7 +76,7 @@ class HandleJson():
 
 if __name__ == '__main__':
     data = ['name','funcups']
-    hj = HandleJson('')
+    hj = HandleJson()
     res = hj.find_key_path('name')
     print(res)
     res1 = hj.find_value_path('funcups')
